/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/

.cke_balloon.cke_balloontoolbar span:last-child a:last-child::after,
.cke_balloon.cke_balloontoolbar span:last-child a:last-child:hover::after,
.cke_balloon.cke_balloontoolbar span:last-child::after
{
	border-right: 0;
}

.cke_balloon.cke_balloontoolbar .cke_combo
{
	margin-bottom: 0;
	margin-right: 2px;
}
