/*
 Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang("uicolor","ar",{title:"منتقي الألوان",options:"Color Options",highlight:"Highlight",selected:"Selected Color",predefined:"مجموعات ألوان معرفة مسبقا",config:"قص السطر إلى الملف config.js"});